bouncing_ball library
Classes
- BouncingBall
- A widget that simulates a bouncing ball inside a given area. The ball can be pushed by dragging (onPanUpdate) and collides with blockers.
- PositionedBlocker
- Represents an obstacle that the ball can collide with.